v_GetRecord: Gets record clusters using viafID or other identifier in the VIAF cluster
record.
Description
Obtains the record cluster in JSON format. Other formats exists, but the more
informative is 'application/json', so it is the only format used in this
function. See https://developer.api.oclc.org/viaf-api
Usage
v_GetRecord(sid, source = "VIAF")
Value
The VIAF record cluster in the JSON format.
Arguments
sid
The identifier in the authority source.
source
The code of the authority source in VIAF (i.e, BNF, BNE, ISNI...).
Details
If source='VIAF' (default) the function uses the "Read by ID" interface of
the API. If other authority source is used, then the function use the
localAuthorityId/authoritySourceCode interface.
See https://developer.api.oclc.org/viaf-api
Note that the returned record may be a VIAF cluster record or a
redirect/scavenged record: the function returns the record as is.